==> zio-aws-kafka_3-5.17.104.10-sources.jar: zio/aws/kafka/model/GetBootstrapBrokersRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetBootstrapBrokersRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest = {
    import GetBootstrapBrokersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
      .builder()
      .clusterArn(__string.unwrap(clusterArn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.GetBootstrapBrokersRequest.ReadOnly =
    zio.aws.kafka.model.GetBootstrapBrokersRequest.wrap(buildAwsValue())
}
object GetBootstrapBrokersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.GetBootstrapBrokersRequest =
      zio.aws.kafka.model.GetBootstrapBrokersRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
  ) extends zio.aws.kafka.model.GetBootstrapBrokersRequest.ReadOnly {
    override val clusterArn: __string =
      zio.aws.kafka.model.primitives.__string(impl.clusterArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
  ): zio.aws.kafka.model.GetBootstrapBrokersRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-5.17.146.1-sources.jar: zio/aws/kafka/model/GetBootstrapBrokersRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetBootstrapBrokersRequest(clusterArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest = {
    import GetBootstrapBrokersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.GetBootstrapBrokersRequest.ReadOnly =
    zio.aws.kafka.model.GetBootstrapBrokersRequest.wrap(buildAwsValue())
}
object GetBootstrapBrokersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.GetBootstrapBrokersRequest =
      zio.aws.kafka.model.GetBootstrapBrokersRequest(clusterArn)
    def clusterArn: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
  ) extends zio.aws.kafka.model.GetBootstrapBrokersRequest.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.GetBootstrapBrokersRequest
  ): zio.aws.kafka.model.GetBootstrapBrokersRequest.ReadOnly = new Wrapper(impl)
}
